==> chromium-45.0.2419.0.tar.xz: chromium-45.0.2419.0/chrome/renderer/worker_content_settings_client_proxy.h <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_
#define CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_

#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
#include "third_party/WebKit/public/web/WebWorkerContentSettingsClientProxy.h"
#include "url/gurl.h"

namespace IPC {
class SyncMessageFilter;
}

namespace content {
class RenderFrame;
}

namespace blink {
class WebFrame;
}

// This proxy is created on the main renderer thread then passed onto
// the blink's worker thread.
class WorkerContentSettingsClientProxy
    : public blink::WebWorkerContentSettingsClientProxy {
 public:
  WorkerContentSettingsClientProxy(content::RenderFrame* render_frame,
                              blink::WebFrame* frame);
  virtual ~WorkerContentSettingsClientProxy();

  // WebWorkerContentSettingsClientProxy overrides.
  virtual bool allowDatabase(const blink::WebString& name,
                             const blink::WebString& display_name,
                             unsigned long estimated_size);
  virtual bool requestFileSystemAccessSync();
  virtual bool allowIndexedDB(const blink::WebString& name);

 private:
  // Loading document context for this worker.
  const int routing_id_;
  bool is_unique_origin_;
  GURL document_origin_url_;
  GURL top_frame_origin_url_;
  scoped_refptr<IPC::SyncMessageFilter> sync_message_filter_;

  DISALLOW_COPY_AND_ASSIGN(WorkerContentSettingsClientProxy);
};

#endif  // CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_

==> chromium-49.0.2604.0.tar.xz: chromium-49.0.2604.0/chrome/renderer/worker_content_settings_client_proxy.h <==
// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_
#define CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_

#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
#include "third_party/WebKit/public/web/WebWorkerContentSettingsClientProxy.h"
#include "url/gurl.h"

namespace IPC {
class SyncMessageFilter;
}

namespace content {
class RenderFrame;
}

namespace blink {
class WebFrame;
}

// This proxy is created on the main renderer thread then passed onto
// the blink's worker thread.
class WorkerContentSettingsClientProxy
    : public blink::WebWorkerContentSettingsClientProxy {
 public:
  WorkerContentSettingsClientProxy(content::RenderFrame* render_frame,
                              blink::WebFrame* frame);
  ~WorkerContentSettingsClientProxy() override;

  // WebWorkerContentSettingsClientProxy overrides.
  bool allowDatabase(const blink::WebString& name,
                     const blink::WebString& display_name,
                     unsigned long estimated_size) override;
  bool requestFileSystemAccessSync() override;
  bool allowIndexedDB(const blink::WebString& name) override;

 private:
  // Loading document context for this worker.
  const int routing_id_;
  bool is_unique_origin_;
  GURL document_origin_url_;
  GURL top_frame_origin_url_;
  scoped_refptr<IPC::SyncMessageFilter> sync_message_filter_;

  DISALLOW_COPY_AND_ASSIGN(WorkerContentSettingsClientProxy);
};

#endif  // CHROME_RENDERER_WORKER_CONTENT_SETTINGS_CLIENT_PROXY_H_
